This directory contains bundled external dependencies that are updated
every once in a while.

Note for distribution packagers: if you want to remove the duplicated
code and depend on a packaged version, we suggest that you simply do a
symbolic link in this directory.